==> smartjob-0.0.23.tar.gz: smartjob-0.0.23/smartjob/app/storage.py <==
from abc import ABC, abstractmethod
from dataclasses import dataclass


class StoragePort(ABC):
    @abstractmethod
    async def download(self, source_bucket: str, source_path: str) -> bytes:
        pass

    @abstractmethod
    async def upload(
        self,
        content: bytes | str,
        destination_bucket: str,
        destination_path: str,
        only_if_not_exists: bool = True,
    ) -> str:
        pass

    @abstractmethod
    async def copy(
        self,
        source_bucket: str,
        source_path: str,
        destination_bucket: str,
        destination_path: str,
        only_if_not_exists: bool = True,
    ) -> str:
        pass


@dataclass
class StorageService:
    adapter: StoragePort

    async def download(self, source_bucket: str, source_path: str) -> bytes:
        return await self.adapter.download(source_bucket, source_path)

    async def upload(
        self,
        content: bytes | str,
        destination_bucket: str,
        destination_path: str,
        only_if_not_exists: bool = True,
    ):
        return await self.adapter.upload(
            content, destination_bucket, destination_path, only_if_not_exists
        )

    async def copy(
        self,
        source_bucket: str,
        source_path: str,
        destination_bucket: str,
        destination_path: str,
        only_if_not_exists: bool = True,
    ):
        return await self.adapter.copy(
            source_bucket,
            source_path,
            destination_bucket,
            destination_path,
            only_if_not_exists=only_if_not_exists,
        )

==> smartjob-0.0.29.tar.gz: smartjob-0.0.29/smartjob/app/storage.py <==
from abc import ABC, abstractmethod
from dataclasses import dataclass

# FIXME: timeouts


class StoragePort(ABC):
    @abstractmethod
    def download(self, source_bucket: str, source_path: str) -> bytes:
        pass

    @abstractmethod
    def upload(
        self,
        content: bytes | str,
        destination_bucket: str,
        destination_path: str,
        only_if_not_exists: bool = True,
    ) -> str:
        pass

    @abstractmethod
    def copy(
        self,
        source_bucket: str,
        source_path: str,
        destination_bucket: str,
        destination_path: str,
        only_if_not_exists: bool = True,
    ) -> str:
        pass


@dataclass
class StorageService:
    adapter: StoragePort

    def download(self, source_bucket: str, source_path: str) -> bytes:
        return self.adapter.download(source_bucket, source_path)

    def upload(
        self,
        content: bytes | str,
        destination_bucket: str,
        destination_path: str,
        only_if_not_exists: bool = True,
    ):
        return self.adapter.upload(
            content, destination_bucket, destination_path, only_if_not_exists
        )

    def copy(
        self,
        source_bucket: str,
        source_path: str,
        destination_bucket: str,
        destination_path: str,
        only_if_not_exists: bool = True,
    ):
        return self.adapter.copy(
            source_bucket,
            source_path,
            destination_bucket,
            destination_path,
            only_if_not_exists=only_if_not_exists,
        )
